@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-from __future__ import print_function
 """Script to commit the doc build outputs into the github-pages repo.
 
 Use:
@@ -15,6 +14,7 @@ something like 'current' as a stable URL for the most current version of the """
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
+from __future__ import print_function
 
 import os
 import shutil
@@ -33,12 +33,6 @@ html_dir = 'build/html'
 pdf_dir = 'build/latex'
 pages_repo = 'git@github.com:ipython/ipython-doc.git'
 
-
-if sys.version_info[0] <= 3: 
-    getcwd = os.getcwd
-else:
-    getcwd = os.getcwdu
-
 #-----------------------------------------------------------------------------
 # Functions
 #-----------------------------------------------------------------------------
@@ -76,7 +70,7 @@ def sh3(cmd):
 def init_repo(path):
     """clone the gh-pages repo if we haven't already."""
     sh("git clone %s %s"%(pages_repo, path))
-    here = getcwd()
+    here = os.getcwdu()
     cd(path)
     sh('git checkout gh-pages')
     cd(here)
@@ -91,7 +85,7 @@ if __name__ == '__main__':
     except IndexError:
         tag = "dev"
     
-    startdir = getcwd()
+    startdir = os.getcwdu()
     if not os.path.exists(pages_dir):
         # init the repo
         init_repo(pages_dir)
@@ -122,7 +116,7 @@ if __name__ == '__main__':
     try:
         cd(pages_dir)
         branch = sh2('git rev-parse --abbrev-ref HEAD').strip()
-        if branch != b'gh-pages':
+        if branch != 'gh-pages':
             e = 'On %r, git branch is %r, MUST be "gh-pages"' % (pages_dir,
                                                                  branch)
             raise RuntimeError(e)
